@@ -101,11 +101,15 @@ def format_rss_result(ref,bebukey=None):
         ref['url'] = ref['url']
     ref['title'] = utils.clean_text(ref['title'])
     tweet = utils.format_tweet(ref['title'],ref['url'],ref['summary'],"",bebukey)['tweet']
+    parsed = utils.summarize_post(ref)
     return {
         'tweet':tweet,
         'title':ref['title'],
-        'summary':utils.clean_text(ref['summary']),
-        'url':ref['url']
+        'url':ref['url'],
+        'summary': parsed['summary'],
+        'author':parsed['author'],
+        'img':parsed['img'],
+        'movies':parsed['movies']
         }
 
 ############################## Nature Blog: ##############################
@@ -113,11 +117,15 @@ def format_nature_blog_result(ref,bebukey):
     full_url = utils.clean_url(ref['id'])
     ref['title'] = utils.clean_text(ref['title'])
     tweet = utils.format_tweet(ref['title'],full_url,ref['summary'],"",bebukey)['tweet']
+    parsed = utils.summarize_post(ref)
     return {
         'tweet':tweet,
         'title':ref['title'],
-        'summary':utils.clean_text(ref['summary']),
-        'url':full_url
+        'url':full_url,
+        'summary': parsed['summary'],
+        'author':parsed['author'],
+        'img':parsed['img'],
+        'movies':parsed['movies']
         }
 
 #################################### BioITWorld: ####################################
@@ -125,11 +133,15 @@ def format_bioitworld_result(ref,bebukey=None):
     full_url = utils.clean_url(ref['link'])
     ref['title'] = utils.clean_text(ref['title'])
     tweet = utils.format_tweet(ref['title'],full_url,ref['title'],"",bebukey)['tweet']
+    parsed = utils.summarize_post(ref)
     return {
         'tweet':tweet,
         'title':ref['title'],
-        'summary':utils.clean_text(ref['summary']),
-        'url':full_url
+        'url':full_url,
+        'summary': parsed['summary'],
+        'author':parsed['author'],
+        'img':parsed['img'],
+        'movies':parsed['movies']
         }
 
 #################################### GenomeWeb: ####################################
@@ -137,11 +149,15 @@ def format_genomeweb_result(ref,bebukey=None):
     full_url = utils.clean_url(ref['link'])
     ref['title'] = utils.clean_text(ref['title'])
     tweet = utils.format_tweet(ref['title'],full_url,ref['summary'],"",bebukey)['tweet']
+    parsed = utils.summarize_post(ref)
     return {
         'tweet':tweet,
         'title':ref['title'],
-        'summary':utils.clean_text(ref['summary']),
-        'url':full_url
+        'url':full_url,
+        'summary': parsed['summary'],
+        'author':parsed['author'],
+        'img':parsed['img'],
+        'movies':parsed['movies']
         }
 
 #################################### Techcrunch: ####################################
@@ -149,11 +165,17 @@ def format_techcrunch_result(ref,bebukey=None):
     full_url = utils.clean_url(ref['link'])
     print("Updated URL for post: "+full_url)
     tweet = utils.format_tweet(ref['title'],full_url,ref['summary'],"",bebukey)['tweet']
+    parsed = utils.summarize_post(ref)
+    print(">>> PARSED")
+    print(parsed)
     return {
             'tweet':tweet,
             'title':utils.clean_text(ref['title']),
-            'summary':utils.clean_text(ref['summary']),
-            'url':full_url
+            'url':full_url,
+            'summary': parsed['summary'],
+            'author':parsed['author'],
+            'img':parsed['img'],
+            'movies':parsed['movies']
         }
 
 #################################### Pubmed: ####################################
@@ -164,11 +186,15 @@ def format_pubmed_result(ref,bebukey=None):
     print("Updated URL for post: "+full_url)
     if(not valid_string(ref['title'],rejects)): raise Exception("Rejecting post: "+ref['title'])
     tweet = utils.format_tweet(ref['title'],full_url,ref['summary'],"",bebukey)['tweet']
+    parsed = utils.summarize_post(ref)
     return {
             'tweet':tweet,
             'title':utils.clean_text(ref['title']),
-            'summary':utils.clean_text(ref['summary']),
-            'url':full_url
+            'url':full_url,
+            'summary': parsed['summary'],
+            'author':parsed['author'],
+            'img':parsed['img'],
+            'movies':parsed['movies']
         }
 
 #################################### Indeed: ####################################
@@ -182,6 +208,7 @@ def format_indeed_result(ref,bebukey=None):
     urls = extractor.find_urls(page)
     links = urls
     print("Got links.")
+    company_url = None
     for link in links:
         if("indeed.com/rc/clk" in link):
             try:
@@ -191,7 +218,7 @@ def format_indeed_result(ref,bebukey=None):
             break
     if(not company_url): raise Exception("No links found")
     ref['url'] = company_url
-    title = utils.clean_text(ref['title']+" | "+ref['summary'])
+    title = utils.clean_text(ref['title'])
     print("title: "+title)
     intro="👍 JOB ALERT👍 "
     tweet = utils.format_tweet(title,ref['url'],"",intro,bebukey)['tweet']
@@ -203,6 +230,7 @@ def format_indeed_result(ref,bebukey=None):
         'url':ref['url'],
         'source':ref['source']
         }
+
 #################################### Get Result: ####################################
 @func_set_timeout(300)
 def format_result(res,res_type='rss',bebukey=None):
@@ -311,6 +339,24 @@ def get_update(feed_name = "techcrunch",c=1,*args,**kwargs):
 def get_multiple(feed_name="techcrunch",c=5,*args,**kwargs):
     return get_update(feed_name,c,args,kwargs)
 
+def get_posts(params=None, count=1,**kwargs):
+    #get the bebukey
+    if('bebukey' in kwargs):
+        bebukey = kwargs['bebukey']
+    else: 
+        bebukey = None 
+    feed = None
+    url = None
+    #get the feed
+    if('feed' in kwargs): feed = kwargs['feed']
+    elif('name' in kwargs['name']): feed = kwargs['name']
+    elif('url' in kwargs): url = kwargs['url']
+    else: feed = 'techcrunch'
+    if(url): posts = get_url(url,count,bebukey)
+    else: posts = get_feed(feed,count,bebukey)
+    if(not posts): raise Exception("No posts found!")
+    return posts
+
 if __name__ == "__main__":
     print("tw")
     # url="https://www.engadget.com/rss.xml" #test of non-specific rss
